@@ -14,6 +14,7 @@ from typing import Tuple
 if util.find_spec("torch"):
 
     import torch
+    import torch.nn as nn
 
     class LeNet(torch.nn.Module):
         """
@@ -153,6 +154,16 @@ if util.find_spec("torch"):
             x = self.fc_3(x)
             return x
 
+    def TitanicSimpleTorchModel() -> torch.nn.Module:
+        return nn.Sequential(
+            nn.Linear(12, 12),
+            nn.Sigmoid(),
+            nn.Linear(12, 8),
+            nn.Sigmoid(),
+            nn.Linear(8, 2),
+            nn.Softmax(dim=1),
+        )
+
 
 if util.find_spec("tensorflow"):
     import tensorflow as tf
@@ -184,7 +195,6 @@ if util.find_spec("tensorflow"):
         )
 
     def ConvNet1DTF(n_channels: int, seq_len: int, n_classes: int) -> tf.keras.Model:
-
         """
         A Tensorflow implementation of 1D-convolutional architecture.
         """
@@ -204,3 +214,31 @@ if util.find_spec("tensorflow"):
                 tf.keras.layers.Dense(n_classes),
             ]
         )
+
+    def TitanicSimpleTFModel() -> tf.keras.Model:
+        return tf.keras.Sequential(
+            [
+                tf.keras.layers.Dense(12, activation="sigmoid"),
+                tf.keras.layers.Dense(12, activation="sigmoid"),
+                tf.keras.layers.Dense(8),
+                tf.keras.layers.Dense(2, activation="softmax"),
+            ]
+        )
+
+    def CifarCNNModel() -> tf.keras.Model:
+        """
+        Source: https://www.tensorflow.org/tutorials/images/cnn
+        """
+
+        return tf.keras.Sequential(
+            [
+                tf.keras.layers.Conv2D(32, (3, 3), activation='relu', input_shape=(32, 32, 3)),
+                tf.keras.layers.MaxPooling2D((2, 2)),
+                tf.keras.layers.Conv2D(64, (3, 3), activation='relu'),
+                tf.keras.layers.MaxPooling2D((2, 2)),
+                tf.keras.layers.Conv2D(64, (3, 3), activation='relu'),
+                tf.keras.layers.Flatten(),
+                tf.keras.layers.Dense(64, activation='relu'),
+                tf.keras.layers.Dense(10),
+            ]
+        )
