@@ -3,7 +3,6 @@ from pytest_lazyfixture import lazy_fixture
 
 from quantus.helpers import utils
 from quantus.functions.perturb_func import *
-from tests.fixtures import *
 
 
 @pytest.fixture
@@ -36,21 +35,6 @@ def input_uniform_2d_3ch_flattened():
     return np.random.uniform(0, 0.1, size=(3, 224, 224)).flatten()
 
 
-@pytest.fixture
-def input_ones_mnist():
-    return np.ones(shape=(1, 28, 28))
-
-
-@pytest.fixture
-def input_ones_mnist_flattened():
-    return np.ones(shape=(1, 28, 28)).flatten()
-
-
-@pytest.fixture
-def input_zeros_mnist_flattened():
-    return np.zeros(shape=(1, 28, 28)).flatten()
-
-
 @pytest.fixture
 def input_uniform_1d_3ch():
     return np.random.uniform(0, 0.1, size=(3, 224))
@@ -82,22 +66,38 @@ def input_uniform_mnist():
     [
         (
             lazy_fixture("input_zeros_2d_3ch"),
-            {"indices": [0, 2], "indexed_axes": [1, 2], "perturb_baseline": 1.0,},
+            {
+                "indices": [0, 2],
+                "indexed_axes": [1, 2],
+                "perturb_baseline": 1.0,
+            },
             1,
         ),
         (
             lazy_fixture("input_zeros_2d_3ch"),
-            {"indices": [0, 2], "indexed_axes": [0], "perturb_baseline": 1.0,},
+            {
+                "indices": [0, 2],
+                "indexed_axes": [0],
+                "perturb_baseline": 1.0,
+            },
             1,
         ),
         (
             lazy_fixture("input_zeros_2d_3ch"),
-            {"indices": [0, 2], "indexed_axes": [0, 1, 2], "perturb_baseline": 1.0,},
+            {
+                "indices": [0, 2],
+                "indexed_axes": [0, 1, 2],
+                "perturb_baseline": 1.0,
+            },
             1,
         ),
         (
             lazy_fixture("input_zeros_2d_3ch_flattened"),
-            {"indices": [0, 2], "indexed_axes": [0], "perturb_baseline": 1.0,},
+            {
+                "indices": [0, 2],
+                "indexed_axes": [0],
+                "perturb_baseline": 1.0,
+            },
             1,
         ),
         (
@@ -167,22 +167,38 @@ def test_baseline_replacement_by_indices(
     [
         (
             lazy_fixture("input_zeros_2d_3ch"),
-            {"indices": [0, 2], "indexed_axes": [1, 2], "input_shift": -1.0,},
+            {
+                "indices": [0, 2],
+                "indexed_axes": [1, 2],
+                "input_shift": -1.0,
+            },
             -1,
         ),
         (
             lazy_fixture("input_zeros_2d_3ch"),
-            {"indices": [0, 2], "indexed_axes": [0], "input_shift": -1.0,},
+            {
+                "indices": [0, 2],
+                "indexed_axes": [0],
+                "input_shift": -1.0,
+            },
             -1,
         ),
         (
             lazy_fixture("input_zeros_2d_3ch"),
-            {"indices": [0, 2], "indexed_axes": [0, 1, 2], "input_shift": -1.0,},
+            {
+                "indices": [0, 2],
+                "indexed_axes": [0, 1, 2],
+                "input_shift": -1.0,
+            },
             -1,
         ),
         (
             lazy_fixture("input_zeros_2d_3ch_flattened"),
-            {"indices": [0, 2], "indexed_axes": [0], "input_shift": -1.0,},
+            {
+                "indices": [0, 2],
+                "indexed_axes": [0],
+                "input_shift": -1.0,
+            },
             -1,
         ),
         (
@@ -332,17 +348,26 @@ def test_baseline_replacement_by_blur(
     [
         (
             lazy_fixture("input_uniform_1d_3ch"),
-            {"indices": [0], "indexed_axes": [0, 1],},
+            {
+                "indices": [0],
+                "indexed_axes": [0, 1],
+            },
             True,
         ),
         (
             lazy_fixture("input_uniform_2d_3ch"),
-            {"indices": [0], "indexed_axes": [0, 1, 2],},
+            {
+                "indices": [0],
+                "indexed_axes": [0, 1, 2],
+            },
             True,
         ),
         (
             lazy_fixture("input_uniform_2d_3ch_flattened"),
-            {"indices": [0], "indexed_axes": [0],},
+            {
+                "indices": [0],
+                "indexed_axes": [0],
+            },
             True,
         ),
     ],
@@ -361,17 +386,29 @@ def test_gaussian_noise(
     [
         (
             lazy_fixture("input_uniform_1d_3ch"),
-            {"perturb_radius": 0.02, "indices": [0], "indexed_axes": [0, 1],},
+            {
+                "perturb_radius": 0.02,
+                "indices": [0],
+                "indexed_axes": [0, 1],
+            },
             True,
         ),
         (
             lazy_fixture("input_uniform_2d_3ch"),
-            {"perturb_radius": 0.02, "indices": [0], "indexed_axes": [0, 1],},
+            {
+                "perturb_radius": 0.02,
+                "indices": [0],
+                "indexed_axes": [0, 1],
+            },
             True,
         ),
         (
             lazy_fixture("input_uniform_2d_3ch_flattened"),
-            {"perturb_radius": 0.02, "indices": [0], "indexed_axes": [0],},
+            {
+                "perturb_radius": 0.02,
+                "indices": [0],
+                "indexed_axes": [0],
+            },
             True,
         ),
     ],
@@ -387,7 +424,13 @@ def test_uniform_noise(
 @pytest.mark.perturb_func
 @pytest.mark.parametrize(
     "data,params,expected",
-    [(lazy_fixture("input_uniform_2d_3ch"), {"perturb_angle": 30}, True,),],
+    [
+        (
+            lazy_fixture("input_uniform_2d_3ch"),
+            {"perturb_angle": 30},
+            True,
+        ),
+    ],
 )
 def test_rotation(data: dict, params: dict, expected: Union[float, dict, bool]):
     out = rotation(arr=data, **params)
@@ -433,7 +476,13 @@ def test_translation_y_direction(
 @pytest.mark.perturb_func
 @pytest.mark.parametrize(
     "data,params,expected",
-    [(lazy_fixture("input_uniform_2d_3ch"), {"perturb_dx": 20}, True,),],
+    [
+        (
+            lazy_fixture("input_uniform_2d_3ch"),
+            {"perturb_dx": 20},
+            True,
+        ),
+    ],
 )
 def test_no_perturbation(
     data: np.ndarray, params: dict, expected: Union[float, dict, bool]
